# Printcleaner: the simplest way to remove print statements from your Python code


![GitHub](https://img.shields.io/github/license/larsvonschaff/printcleaner)
![PyPI](https://img.shields.io/pypi/v/printcleaner)


### Is your Python code littered with random print statements from debugging or simply exploring?

Printcleaner is a simple CLI that removes all of them with one command. All you need to do is:


```pip install printcleaner ```

```clean < name of your file or directory > ```

Done. Don't worry: comments, formatting, whitespace and everything else in your code will be preserved.

